@@ -6,7 +6,7 @@
 
 #Author: Christos Zamantzas <christos.zamantzas@gmail.com>
 #Contributions: Frank Visser - import, decrypt and encrypt from config file the user variables.
-#Version: 0.6-0
+#Version: 0.6-1
 
 import os
 import sys
@@ -259,10 +259,9 @@ class MyStartupDialog(QtGui.QDialog): ### FIXME: add 3 re-tries for wrong passwo
           if doCheckPassword(EnteredPassword) == True:
              message = 'Password Correct'
              showQuickMessage(message)
+
              self.close()
              return True
-             ##make a copy of the config for editing
-             doCopyConfig()
 
           else:
              message = 'Incorrect Password; Exiting..'
@@ -282,6 +281,8 @@ class MyStartupDialog(QtGui.QDialog): ### FIXME: add 3 re-tries for wrong passwo
 
 class MyMainWindow(QtGui.QMainWindow):
        def __init__(self, parent=None):
+          ##make a copy of the config for editing
+          doCopyConfig()
 
           #Open Start Dialog - request password
           mydialog = MyStartupDialog()
@@ -805,6 +806,15 @@ class smsconEditorMain():
           ##Check if temp folder is available   
           if os.path.exists(Path) == False:
              os.system('mkdir %s' % Path)
+             message ='First Time Use: Creating temp folders..'
+             showQuickMessage(message)
+          else:
+             pass
+          ##Check if temp config file available
+          if CheckFile(Path, ConfigFile) == False:
+             message ='First Time Use: Creating temp folders..'
+             showQuickMessage(message)
+             doCopyConfig()
           else:
              pass
             
